#!/bin/sh -eu
#! -*- coding:utf-8; -*-

# Copyright (C) 2013 Moritz Klammler <moritz@klammler.eu>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

set -eu

PROGRAM='fail-missing.sh'
VERSION='1.0'
USAGE="$PROGRAM PROGRAM VARIABLE"
helptext="usage: $USAGE

Output an error message that informs the user that something cannot be built
because PROGRAM is missing.  Suggest installing it and setting VARIABLE to the
file name of executable.  (An according '...FLAGS' variable is assumed.)


Options:

--help      show this text and exit
--version   show version information and exit


Exits Status:

On successful operation the exit status is 0, on error, it is 1 and if invalid
arguments are passed, it will be 2."
versiontext="$PROGRAM $VERSION
Copyright (C) 2013 Moritz Klammler <moritz@klammler.eu>
This is free software; see the source for copying conditions.  There is NO
warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."

## usage: uerror MESSAGE...
##
## Print the error MESSAGEs and the usage synopsis, then exit with status 2.
##
uerror()
{
    echo "$PROGRAM: error: $@" >&2
    echo "usage: $USAGE" >&2
    exit 2
}

onlyargs=0
for arg in "$@"
do
    if test $onlyargs -eq 0
    then
        case "$arg" in
            --help)
                echo "$helptext"
                exit 0
                ;;
            --version)
                echo "$versiontext"
                exit 0
                ;;
            --)
                onlyargs=1
                ;;
            -*)
                uerror "unrecognized option \`$arg'"
                ;;
            *)
                if test "x$program" = x
                then
                    program="$arg"
                elif test "x$variable" = x
                then
                    variable="$arg"
                else
                    uerror "too many arguments"
                fi
                ;;
        esac
    else
        if test "x$program" = x
        then
            program="$arg"
        elif test "x$variable" = x
        then
            variable="$arg"
        else
            uerror "too many arguments"
        fi
    fi
done
unset arg onlyargs
if test "x$program" = x || test "x$variable" = x
then
    uerror "too few arguments"
fi

flagsvariable="$2FLAGS"

cat <<EOF >&2
error: missing $program

Please make sure that a recent version of $program is installed on your system
and can be used.  If you did so, please re-run the \`configure' script.  If the
error doesn't go away, please pass the absolute path to your local $program
installation via the $variable variable to \`configure'.  If $program needs any
unusual options in order to function correctly, you can pass them in the
variable $flagsvariable.

Example:

    $ ./configure $variable=/usr/bin/$program $flagsvariable='-y --lambda=2' [...]
EOF
exit 0
